"""An API wrapper to get stats from the Minecraft server Hypixel, mc.hypixel.net.

So far the user can get stats from the duels lobby.

Go to the README.md for usage.
"""
from .errors import *
from .minecraftstats import *